==> dde-file-manager_5.8.1.orig.tar.xz: dde-file-manager-5.8.1/src/dde-desktop/translations/dde-desktop.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en">
<context>
    <name>CanvasGridView</name>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3474"/>
        <source>Icon size</source>
        <translation>Icon size</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3483"/>
        <source>Auto merge</source>
        <translation>Auto merge</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3495"/>
        <source>Auto arrange</source>
        <translation>Auto arrange</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3534"/>
        <source>Corner Settings</source>
        <translation>Corner Settings</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3543"/>
        <location filename="../view/canvasgridview.cpp" line="3548"/>
        <source>Set Wallpaper</source>
        <translation>Set Wallpaper</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3546"/>
        <source>Wallpaper and Screensaver</source>
        <translation>Wallpaper and Screensaver</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3732"/>
        <source>Properties</source>
        <translation>Properties</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3524"/>
        <source>Display Settings</source>
        <translation>Display Settings</translation>
    </message>
</context>
<context>
    <name>DesktopItemDelegate</name>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="23"/>
        <source>Tiny</source>
        <translation>Tiny</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="24"/>
        <source>Small</source>
        <translation>Small</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="25"/>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="26"/>
        <source>Large</source>
        <translation>Large</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="27"/>
        <source>Super large</source>
        <translation>Super large</translation>
    </message>
</context>
<context>
    <name>DesktopMain</name>
    <message>
        <location filename="../main.cpp" line="158"/>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
</context>
<context>
    <name>Frame</name>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="700"/>
        <source>Wallpaper Slideshow</source>
        <translation>Wallpaper Slideshow</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="746"/>
        <source>When login</source>
        <translation>When login</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="748"/>
        <source>When wakeup</source>
        <translation>When wakeup</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="800"/>
        <source>Require a password on wakeup</source>
        <translation>Require a password on wakeup</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="832"/>
        <source>Never</source>
        <translation>Never</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="834"/>
        <source>Wait:</source>
        <translation>Wait:</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="867"/>
        <source>Wallpaper</source>
        <translation>Wallpaper</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="879"/>
        <source>Screensaver</source>
        <translation>Screensaver</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="944"/>
        <source>Loading wallpapers...</source>
        <translation>Loading wallpapers...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="946"/>
        <source>Loading screensavers...</source>
        <translation>Loading screensavers...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1004"/>
        <source>Desktop</source>
        <comment>button</comment>
        <translation>Desktop</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1005"/>
        <source>Lock Screen</source>
        <comment>button</comment>
        <translation>Lock Screen</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1006"/>
        <source>Both</source>
        <translation>Both</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1094"/>
        <source>Custom Screensaver</source>
        <translation>Custom Screensaver</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1095"/>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1097"/>
        <source>Apply</source>
        <comment>button</comment>
        <translation>Apply</translation>
    </message>
</context>
<context>
    <name>WaterMaskFrame</name>
    <message>
        <location filename="../view/watermaskframe.cpp" line="127"/>
        <location filename="../view/watermaskframe.cpp" line="128"/>
        <source>Not authorized</source>
        <translation>Not authorized</translation>
    </message>
    <message>
        <location filename="../view/watermaskframe.cpp" line="136"/>
        <location filename="../view/watermaskframe.cpp" line="137"/>
        <source>In trial period</source>
        <translation>In trial period</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.8.3.orig.tar.xz: dde-file-manager-5.8.3/src/dde-desktop/translations/dde-desktop.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>CanvasGridView</name>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3474"/>
        <source>Icon size</source>
        <translation>Icon size</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3483"/>
        <source>Auto merge</source>
        <translation>Auto merge</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3495"/>
        <source>Auto arrange</source>
        <translation>Auto arrange</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3534"/>
        <source>Corner Settings</source>
        <translation>Corner Settings</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3543"/>
        <location filename="../view/canvasgridview.cpp" line="3548"/>
        <source>Set Wallpaper</source>
        <translation>Set Wallpaper</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3546"/>
        <source>Wallpaper and Screensaver</source>
        <translation>Wallpaper and Screensaver</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3732"/>
        <source>Properties</source>
        <translation>Properties</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3524"/>
        <source>Display Settings</source>
        <translation>Display Settings</translation>
    </message>
</context>
<context>
    <name>DesktopItemDelegate</name>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="23"/>
        <source>Tiny</source>
        <translation>Tiny</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="24"/>
        <source>Small</source>
        <translation>Small</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="25"/>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="26"/>
        <source>Large</source>
        <translation>Large</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="27"/>
        <source>Super large</source>
        <translation>Super large</translation>
    </message>
</context>
<context>
    <name>DesktopMain</name>
    <message>
        <location filename="../main.cpp" line="158"/>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
</context>
<context>
    <name>Frame</name>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="700"/>
        <source>Wallpaper Slideshow</source>
        <translation>Wallpaper Slideshow</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="746"/>
        <source>When login</source>
        <translation>When login</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="748"/>
        <source>When wakeup</source>
        <translation>When wakeup</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="800"/>
        <source>Require a password on wakeup</source>
        <translation>Require a password on wakeup</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="832"/>
        <source>Never</source>
        <translation>Never</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="834"/>
        <source>Wait:</source>
        <translation>Wait:</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="867"/>
        <source>Wallpaper</source>
        <translation>Wallpaper</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="879"/>
        <source>Screensaver</source>
        <translation>Screensaver</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="944"/>
        <source>Loading wallpapers...</source>
        <translation>Loading wallpapers...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="946"/>
        <source>Loading screensavers...</source>
        <translation>Loading screensavers...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1004"/>
        <source>Desktop</source>
        <comment>button</comment>
        <translation>Desktop</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1005"/>
        <source>Lock Screen</source>
        <comment>button</comment>
        <translation>Lock Screen</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1006"/>
        <source>Both</source>
        <translation>Both</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1094"/>
        <source>Custom Screensaver</source>
        <translation>Custom Screensaver</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1095"/>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1097"/>
        <source>Apply</source>
        <comment>button</comment>
        <translation>Apply</translation>
    </message>
</context>
<context>
    <name>WaterMaskFrame</name>
    <message>
        <location filename="../view/watermaskframe.cpp" line="127"/>
        <location filename="../view/watermaskframe.cpp" line="128"/>
        <source>Not authorized</source>
        <translation>Not authorized</translation>
    </message>
    <message>
        <location filename="../view/watermaskframe.cpp" line="136"/>
        <location filename="../view/watermaskframe.cpp" line="137"/>
        <source>In trial period</source>
        <translation>In trial period</translation>
    </message>
</context>
</TS>
